export P=sqlite3
export V=3.25.3
export B=1
export MAINTAINER=JuergenFischer

savelog() {
	local f=$1
	rm -f $f.9
	for i in $(seq 8 -1 0); do [ -f "$f.$i" ] && mv $f.$i $f.$(( i + 1 )); done
	[ -f $f ] && mv $f $f.0
}

savelog package.log
exec > >(tee package.log) 2>&1
date

set -e

export BASE=sqlite-amalgamation-3250300

[ -f $BASE.zip ] || wget https://www.sqlite.org/2018/$BASE.zip
if ! [ -d ../$BASE ]; then
	cd ..
	unzip osgeo4w/$BASE.zip
	cd osgeo4w
fi

if ! [ -d "$OSGEO4W_REP" ]; then
        echo no repository
        exit 1
fi

# override msys
cat() { /bin/cat "$@"; }
cp() { /bin/cp "$@"; }
rm() { /bin/rm "$@"; }
mkdir() { /bin/mkdir "$@"; }
tar() { /bin/tar "$@"; }
ls() { /bin/ls "$@"; }
sed() { /bin/sed "$@"; }
diff() { /bin/diff "$@"; }
find() { /bin/find "$@"; }
xargs() { /bin/xargs "$@"; }
declare -x cat cp rm mkdir tar ls sed diff

#
# run batch file and source environment changes
#
fetchenv() {
        local IFS
        IFS=
        batch=$1
        shift

        if ! [ -f "$batch" ]; then
                echo "$batch not found"
                return 1
        fi

        srcenv=$(mktemp /tmp/srcenv.XXXXXXXXXX)
        dstenv=$(mktemp /tmp/dstenv.XXXXXXXXXX)
        diffenv=$(mktemp /tmp/diffenv.XXXXXXXXXX)
        envdiff=$(mktemp /tmp/envdiff.XXXXXXXXXX)
        cmd /c set >$srcenv
        cmd /c call $(cygpath -w $batch) "$@" \>nul 2\>nul \& set >$dstenv
        cat <<EOF >$envdiff
/^+++/d;
/^[^+]/d;
s/^+//;
# s/\\\\/\\\\\\\\/g;
/^PATH=/ {
        s/\\\\/\\//g;
        s#\\([=;]\\)\\([a-zA-Z]\\):#\\1/cygdrive/\\2#g;
        s/;/:/g;
}
s/;/\\\\;/g;
s/^/export /;
s/=/='/;
s/\\\\r//g;
s/\r$/'/;
EOF
        diff -u $srcenv $dstenv | sed -f $envdiff >$diffenv
        . $diffenv
        PATH=$PATH:/bin:/usr/bin:/cygdrive/c/windows32/system32:/cygdrive/c/windows
        rm -f $srcenv $dstenv $diffenv $envdiff
}

for ARCH in ${ARCHS:-x86 x86_64}; do
	export ARCH

	(
		case "$ARCH" in
		x86)
			export OSGEO4W_ROOT="C:\\OSGeo4W"
			export VCARCH=x86
			;;

		x86_64)
			export OSGEO4W_ROOT="C:\\OSGeo4W64"
			export VCARCH=amd64
			;;

		*)
			echo "Unsupported arch $ARCH" >&2
			exit 1
			;;
		esac

		fetchenv $OSGEO4W_ROOT/bin/o4w_env.bat

		R=$OSGEO4W_REP/$ARCH/release/$P
		mkdir -p $R

		fetchenv /cygdrive/c/Program\ Files*/Microsoft\ Visual\ Studio\ 14.0/VC/vcvarsall.bat $VCARCH
		PATH=/cygdrive/c/Program\ Files*/Microsoft\ Visual\ Studio\ 14.0/Common7/IDE:$PATH

		cat <<EOF >$R/setup.hint
sdesc: "The SQLite3 library for accessing SQLite3 database files."
ldesc: "The SQLite3 library for accessing SQLite3 database files."
maintainer: $MAINTAINER
category: Libs
requires: msvcrt2015
EOF

		cat <<EOF >$R/$P-$V-$B.txt
SQLite Copyright
  
All of the code and documentation in SQLite has been dedicated to the public
domain by the authors. All code authors, and representatives of the companies
they work for, have signed affidavits dedicating their contributions to the
public domain and originals of those signed affidavits are stored in a firesafe
at the main offices of Hwaci. Anyone is free to copy, modify, publish, use,
compile, sell, or distribute the original SQLite code, either in source code
form or as a compiled binary, for any purpose, commercial or non-commercial,
and by any means.

The previous paragraph applies to the deliverable code and documentation in
SQLite - those parts of the SQLite library that you actually bundle and ship
with a larger application. Some scripts used as part of the build process (for
example the "configure" scripts generated by autoconf) might fall under other
open-source licenses. Nothing from these build scripts ever reaches the final
deliverable SQLite library, however, and so the licenses associated with those
scripts should not be a factor in assessing your rights to copy and use the
SQLite library.

All of the deliverable code in SQLite has been written from scratch. No code
has been taken from other projects or from the open internet. Every line of
code can be traced back to its original author, and all of those authors have
public domain dedications on file. So the SQLite code base is clean and is
uncontaminated with licensed code from other projects.
EOF

		mkdir -p build-$ARCH
		cd build-$ARCH

		nmake /f ..\\makefile.vc INSTDIR=../install-$ARCH SRC=../../$BASE clean all install

		cd ..


		tar -C install-$ARCH -cjf $R/$P-$V-$B.tar.bz2 bin include lib
		tar -C .. -cjf $R/$P-$V-$B-src.tar.bz2 osgeo4w/package.sh osgeo4w/makefile.vc osgeo4w/nmake.opt
	)
done
